# Welcome to geoai

[![image](https://img.shields.io/pypi/v/geoai-py.svg)](https://pypi.python.org/pypi/geoai-py)
[![image](https://img.shields.io/conda/vn/conda-forge/geoai.svg)](https://anaconda.org/conda-forge/geoai)

**A Python package for using Artificial Intelligence (AI) with geospatial data**

-   Free software: MIT license
-   Documentation: <https://geoai.gishub.org>

## Features

-   Visualizing geospatial data, including vector, raster, and LiDAR data
-   Segmenting remote sensing imagery with the Segment Anything Model
-   Classifying remote sensing imagery with deep learning models
